"""Core functionality for WiFi profiler."""

from .models import (
    ConnectionQuality,
    InterfaceInfo,
    WiFiStats,
    PingResult,
    PingSummary,
    ThroughputResult,
    TestSession,
    SessionSummary,
    Config
)
from .system_detect import get_system_info, check_network_connectivity, get_wireless_interfaces
from .wifi_stats import WiFiStatsCollector, get_current_wifi_stats, get_interface_details, list_wireless_interfaces
from .ping import PingTester, ping_host, ping_hosts, format_ping_summary
from .throughput import ThroughputTester, test_download_speed, test_upload_speed, test_bandwidth, format_throughput_result

__all__ = [
    # Models
    "ConnectionQuality",
    "InterfaceInfo", 
    "WiFiStats",
    "PingResult",
    "PingSummary",
    "ThroughputResult",
    "TestSession",
    "SessionSummary",
    "Config",
    
    # System detection
    "get_system_info",
    "check_network_connectivity",
    "get_wireless_interfaces",
    
    # WiFi stats
    "WiFiStatsCollector",
    "get_current_wifi_stats",
    "get_interface_details", 
    "list_wireless_interfaces",
    
    # Ping testing
    "PingTester",
    "ping_host",
    "ping_hosts",
    "format_ping_summary",
    
    # Throughput testing
    "ThroughputTester",
    "test_download_speed",
    "test_upload_speed", 
    "test_bandwidth",
    "format_throughput_result"
] 